<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
<html lang="en">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    {% block head %}
    <link rel="stylesheet" href="/gleam/css/bootstrap.css" />
    <title>{% block title %}{% endblock %}</title>
    {% block css %}
    {% endblock %}
    {% endblock %}
</head>
<body>
    <div class="container">
        <div id="content">{% block content %}{% endblock %}</div>
        <div id="footer">
            {% block footer %}
            {% endblock %}
        </div>
    </div>
</body>
<!-- <script src="//ajax.googleapis.com/ajax/libs/jquery/2.1.0/jquery.min.js"></script> -->
<script src="/gleam/js/jquery.min.js"></script>
<script src="/gleam/js/jquery.form.js"></script>
<script src="/gleam/js/bootstrap.js"></script>
{% block js %}{% endblock %}
</html>
