<div class="loader"
    id="{{ name }}_loader"
    style="{% if height %}height: {{ height }}px; {% endif %} 
    {% if width %}width: {{ width }}px; {% endif %}"
>
<img src="/gleam/images/ajax-loader.gif" class="img-loader">
</div>