<div class="{{ column_class }}">
<ul class="nav nav-tabs">
    {% for tab in tabs%}
    {% set navloop = loop %}
        <li{% if navloop.index == 1 %} class="active"{% endif %}><a href="#{{ tab.id() }}-tab" data-toggle="tab"  id="{{ tab.id() }}">{{ tab.name }}</a></li>
    {% endfor %}
</ul>
<div class="tab-content">
  {% for tab in tabs %}
  {% set tabloop = loop %}
      <div class="tab-pane{% if tabloop.index == 1 %} active{% endif %}" id="{{ tab.id() }}-tab">
          {{ tab.render() }}
      </div>
  {% endfor %}
</div>
</div>