<div class="{{ column_class }}">
{% include 'overlay.html' %}
<img class="output"
    id="{{ name }}" 
    {% if height %}height="{{ height }}"{% endif %} 
    {% if width %}width="{{ width }}"{% endif %} 
    src=""
>
</div>