.loader {
    z-index: 1;
    position: absolute;
    display: block;
    background-color: white;
}

.img-loader {
    position: absolute;
    margin: auto;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
}

.output {
    z-index: -1;
    position: absolute;
}
